@@ -6,6 +6,10 @@
 #'
 #' Get a table with links to available data files for the specified data version. Optionally check (see arguments) the file size and availability of data files previously downloaded into the cache directory specified with SPANISH_OD_DATA_DIR environment variable (set by [spod_set_data_dir()]) or a custom path specified with `data_dir` argument. By default the data is fetched from Amazon S3 bucket where the data is stored. If that fails, the function falls back to downloading an XML file from the Spanish Ministry of Transport website. You can also control this behaviour with `use_s3` argument.
 #'
+#' For detailed data descriptions, see package vignettes using [`spod_codebook(ver = 1)`][spod_codebook] and [`spod_codebook(ver = 2)`][spod_codebook] and official methodology documents in **References** section.
+#'
+#' @template references
+#'
 #' @param ver Integer. Can be 1 or 2. The version of the data to use. v1 spans 2020-2021, v2 covers 2022 and onwards. See more details in codebooks with [spod_codebook()].
 #' @param check_local_files Logical. Whether to check if the local files exist and get the file size. Defaults to `FALSE`.
 #' @param data_dir The directory where the data is stored. Defaults to the value returned by `spod_get_data_dir()`.
@@ -94,15 +98,18 @@ spod_available_data <- function(
 #' @keywords internal
 spod_get_latest_v1_file_list <- function(
   data_dir = spod_get_data_dir(),
-  xml_url = "https://opendata-movilidad.mitma.es/RSS.xml"
+  xml_url = "https://opendata-movilidad.mitma.es/RSS.xml",
+  quiet = FALSE
 ) {
   if (!dir.exists(data_dir)) {
     fs::dir_create(data_dir)
   }
 
   current_date <- format(Sys.Date(), format = "%Y-%m-%d")
-  current_filename <- glue::glue(
-    "{data_dir}/{spod_subfolder_metadata_cache()}/data_links_v1_{current_date}.xml"
+  current_filename <- fs::path(
+    data_dir,
+    spod_subfolder_metadata_cache(),
+    glue::glue("data_links_v1_{current_date}.xml")
   )
 
   # ensure dir exists
@@ -110,7 +117,9 @@ spod_get_latest_v1_file_list <- function(
     fs::dir_create(dirname(current_filename), recurse = TRUE)
   }
 
-  message("Saving the file to: ", current_filename)
+  if (!quiet) {
+    message("Saving the file to: ", current_filename)
+  }
   utils::download.file(xml_url, current_filename, mode = "wb")
   # disable curl::multi_download() for now
   # xml_requested <- curl::multi_download(
@@ -140,28 +149,39 @@ spod_available_data_v1 <- function(
   force = FALSE,
   quiet = FALSE
 ) {
-  metadata_folder <- glue::glue("{data_dir}/{spod_subfolder_metadata_cache()}")
+  metadata_folder <- fs::path(data_dir, spod_subfolder_metadata_cache())
   if (!dir.exists(metadata_folder)) {
     fs::dir_create(metadata_folder)
   }
 
+  s3_successful <- FALSE
+
   if (use_s3) {
     files_table <- tryCatch(
       {
-        spod_available_data_s3(ver = 1, force = force, quiet = quiet)
+        files_table_s3 <- spod_available_data_s3(
+          ver = 1,
+          force = force,
+          quiet = quiet
+        )
+        s3_successful <- TRUE
+        files_table_s3
       },
       error = function(e) {
-        message(
-          "S3 fetch failed (",
-          e$message,
-          "); falling back to XML sequence."
-        )
+        if (!quiet) {
+          message(
+            "S3 fetch failed (",
+            e$message,
+            "); falling back to XML sequence."
+          )
+        }
         read_data_links_xml(
           metadata_folder = metadata_folder,
           data_dir = data_dir,
           force = force,
           quiet = quiet,
-          latest_file_function = spod_get_latest_v1_file_list
+          latest_file_function = spod_get_latest_v1_file_list,
+          ver = 1
         )
       }
     )
@@ -171,7 +191,8 @@ spod_available_data_v1 <- function(
       data_dir = data_dir,
       force = force,
       quiet = quiet,
-      latest_file_function = spod_get_latest_v1_file_list
+      latest_file_function = spod_get_latest_v1_file_list,
+      ver = 1
     )
   }
 
@@ -188,12 +209,13 @@ spod_available_data_v1 <- function(
   ))
   # order by pub_ts
   files_table <- files_table[order(files_table$pub_ts, decreasing = TRUE), ]
-  files_table$local_path <- file.path(
+  files_table$local_path <- fs::path(
     data_dir,
+    spod_subfolder_raw_data_cache(ver = 1),
     stringr::str_replace(
       files_table$target_url,
       ".*mitma.es/",
-      spod_subfolder_raw_data_cache(ver = 1)
+      ""
     )
   )
 
@@ -240,8 +262,8 @@ spod_available_data_v1 <- function(
 
   # replace all municipal data download links with districts links
   # this is to address the bugs described in detail in:
-  # http://www.ekotov.pro/mitma-data-issues/issues/011-v1-tpp-mismatch-zone-ids-in-table-and-spatial-data.html
-  # http://www.ekotov.pro/mitma-data-issues/issues/012-v1-tpp-district-files-in-municipality-folders.html
+  # https://www.ekotov.pro/mitma-data-issues/issues/011-v1-tpp-mismatch-zone-ids-in-table-and-spatial-data.html
+  # https://www.ekotov.pro/mitma-data-issues/issues/012-v1-tpp-district-files-in-municipality-folders.html
   # the decision was to use distrcit data and aggregate it to replicate municipal data
   files_table$target_url <- gsub(
     "mitma-municipios",
@@ -306,11 +328,11 @@ spod_available_data_v1 <- function(
     )
 
   # add known file sizes from cached data
-  if (use_s3) {
+  if (s3_successful) {
     # replace remote file sizes for v1
     replacement_file_sizes_distr <- files_table |>
       dplyr::filter(grepl("mitma-distr", .data$local_path)) |>
-      dplyr::select(.data$target_url, .data$file_size_bytes)
+      dplyr::select("target_url", "file_size_bytes")
     replaced_file_sizes_municip <- files_table |>
       dplyr::filter(grepl("mitma-municip", .data$local_path)) |>
       dplyr::select(-"file_size_bytes") |>
@@ -382,6 +404,11 @@ spod_available_data_v1 <- function(
       ) |>
       dplyr::select(-"true_etag")
 
+    files_table$remote_file_size_mb <- round(
+      files_table$file_size_bytes / 1024^2,
+      2
+    )
+
     # if there are files with missing sizes, impute them
     if (any(is.na(files_table$remote_file_size_mb))) {
       # impute uknown file sizes
@@ -412,6 +439,13 @@ spod_available_data_v1 <- function(
         files_table$remote_file_size_mb
       )] <- mean(files_table$mean_file_size_mb)
 
+      # Update file_size_bytes if NA based on remote_file_size_mb
+      files_table$file_size_bytes <- dplyr::if_else(
+        condition = is.na(files_table$file_size_bytes),
+        true = round(files_table$remote_file_size_mb * 1024^2),
+        false = files_table$file_size_bytes
+      )
+
       # Clean up temporary columns
       files_table <- files_table |>
         dplyr::select(-"mean_file_size_mb", -"file_category")
@@ -445,15 +479,18 @@ spod_available_data_v1 <- function(
 #' @keywords internal
 spod_get_latest_v2_file_list <- function(
   data_dir = spod_get_data_dir(),
-  xml_url = "https://movilidad-opendata.mitma.es/RSS.xml"
+  xml_url = "https://movilidad-opendata.mitma.es/RSS.xml",
+  quiet = FALSE
 ) {
   if (!dir.exists(data_dir)) {
     fs::dir_create(data_dir)
   }
 
   current_date <- format(Sys.Date(), format = "%Y-%m-%d")
-  current_filename <- glue::glue(
-    "{data_dir}/{spod_subfolder_metadata_cache()}/data_links_v2_{current_date}.xml"
+  current_filename <- fs::path(
+    data_dir,
+    spod_subfolder_metadata_cache(),
+    glue::glue("data_links_v2_{current_date}.xml")
   )
 
   # ensure dir exists
@@ -461,7 +498,9 @@ spod_get_latest_v2_file_list <- function(
     fs::dir_create(dirname(current_filename), recurse = TRUE)
   }
 
-  message("Saving the file to: ", current_filename)
+  if (!quiet) {
+    message("Saving the file to: ", current_filename)
+  }
   utils::download.file(xml_url, current_filename, mode = "wb")
   # disable curl::multi_download() for now
   # xml_requested <- curl::multi_download(
@@ -492,28 +531,39 @@ spod_available_data_v2 <- function(
   force = FALSE,
   quiet = FALSE
 ) {
-  metadata_folder <- glue::glue("{data_dir}/{spod_subfolder_metadata_cache()}")
+  metadata_folder <- fs::path(data_dir, spod_subfolder_metadata_cache())
   if (!dir.exists(metadata_folder)) {
     fs::dir_create(metadata_folder)
   }
 
+  s3_successful <- FALSE
+
   if (use_s3) {
     files_table <- tryCatch(
       {
-        spod_available_data_s3(ver = 2, force = force, quiet = quiet)
+        files_table_s3 <- spod_available_data_s3(
+          ver = 2,
+          force = force,
+          quiet = quiet
+        )
+        s3_successful <- TRUE
+        files_table_s3
       },
       error = function(e) {
-        message(
-          "S3 fetch failed (",
-          e$message,
-          "); falling back to XML sequence."
-        )
+        if (!quiet) {
+          message(
+            "S3 fetch failed (",
+            e$message,
+            "); falling back to XML sequence."
+          )
+        }
         read_data_links_memoised(
           metadata_folder = metadata_folder,
           data_dir = data_dir,
           force = force,
           quiet = quiet,
-          latest_file_function = spod_get_latest_v2_file_list
+          latest_file_function = spod_get_latest_v2_file_list,
+          ver = 2
         )
       }
     )
@@ -523,7 +573,8 @@ spod_available_data_v2 <- function(
       data_dir = data_dir,
       force = force,
       quiet = quiet,
-      latest_file_function = spod_get_latest_v2_file_list
+      latest_file_function = spod_get_latest_v2_file_list,
+      ver = 2
     )
   }
 
@@ -540,12 +591,13 @@ spod_available_data_v2 <- function(
   ))
   # order by pub_ts
   files_table <- files_table[order(files_table$pub_ts, decreasing = TRUE), ]
-  files_table$local_path <- file.path(
+  files_table$local_path <- fs::path(
     data_dir,
+    spod_subfolder_raw_data_cache(ver = 2),
     stringr::str_replace(
       files_table$target_url,
       ".*mitma.es/",
-      spod_subfolder_raw_data_cache(ver = 2)
+      ""
     )
   )
   files_table$local_path <- stringr::str_replace_all(
@@ -630,7 +682,7 @@ spod_available_data_v2 <- function(
     )
 
   # add known file sizes from cached data
-  if (use_s3) {
+  if (s3_successful) {
     files_table$remote_file_size_mb <- round(
       files_table$file_size_bytes / 1024^2,
       2
@@ -703,6 +755,11 @@ spod_available_data_v2 <- function(
         size_by_file_category,
         by = "file_category"
       )
+
+      if (!"file_size_bytes" %in% names(files_table)) {
+        files_table$file_size_bytes <- NA_real_
+      }
+
       files_table <- files_table |>
         dplyr::mutate(
           size_imputed = ifelse(is.na(.data$remote_file_size_mb), TRUE, FALSE)
@@ -719,6 +776,12 @@ spod_available_data_v2 <- function(
               is.na(.data$remote_file_size_mb),
               .data$mean_file_size_mb,
               .data$remote_file_size_mb
+            ),
+            # Update file_size_bytes if NA based on remote_file_size_mb
+            file_size_bytes = dplyr::if_else(
+              condition = is.na(.data$file_size_bytes),
+              true = round(.data$remote_file_size_mb * 1024^2),
+              false = .data$file_size_bytes
             )
           )
       }
@@ -752,12 +815,13 @@ read_data_links_xml <- function(
   data_dir,
   force = FALSE,
   quiet = FALSE,
-  latest_file_function
+  latest_file_function,
+  ver
 ) {
   xml_files_list <- fs::dir_ls(
     metadata_folder,
     type = "file",
-    regexp = "data_links_v1"
+    regexp = glue::glue("data_links_v{ver}")
   ) |>
     sort()
   latest_file <- utils::tail(xml_files_list, 1)
@@ -774,7 +838,8 @@ read_data_links_xml <- function(
       message("Fetching latest data links xml")
     }
     latest_data_links_xml_path <- latest_file_function(
-      data_dir = data_dir
+      data_dir = data_dir,
+      quiet = quiet
     )
   } else {
     if (!quiet) {
